@@ -4,7 +4,7 @@ package Dist::Zilla::MintingProfile::Author::ETHER;
 # ABSTRACT: Mint distributions like ETHER does
 # vim: set ts=8 sts=4 sw=4 tw=78 et :
 
-our $VERSION = '0.093';
+our $VERSION = '0.094';
 
 use Moose;
 with 'Dist::Zilla::Role::MintingProfile';
@@ -42,7 +42,7 @@ Dist::Zilla::MintingProfile::Author::ETHER - Mint distributions like ETHER does
 
 =head1 VERSION
 
-version 0.093
+version 0.094
 
 =head1 SYNOPSIS
 
@@ -89,6 +89,20 @@ Presently the same as C<github>. Available since version 0.087.
 
 =back
 
+=head1 SEE ALSO
+
+=over 4
+
+=item *
+
+L<Dist::Zilla::PluginBundle::Author::ETHER>
+
+=item *
+
+L<Pod::Weaver::PluginBundle::Author::ETHER>
+
+=back
+
 =head1 SUPPORT
 
 =for stopwords irc
