@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.092-11-ge557d6e
+package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.093-24-g8e63070
 # ABSTRACT: A plugin bundle for distributions built by ETHER
 # KEYWORDS: author bundle distribution tool
 # vim: set ts=8 sts=4 sw=4 tw=78 et :
 
-our $VERSION = '0.093';
+our $VERSION = '0.094';
 
 use Moose;
 with
@@ -16,7 +16,6 @@ with
 use Dist::Zilla::Util;
 use Moose::Util::TypeConstraints qw(enum subtype where);
 use List::Util 1.33 qw(first any);
-use List::MoreUtils 'uniq';
 use Module::Runtime 'require_module';
 use Devel::CheckBin 'can_run';
 use Path::Tiny;
@@ -66,7 +65,7 @@ has copy_file_from_release => (
 
 around copy_files_from_release => sub {
     my $orig = shift; my $self = shift;
-    uniq $self->$orig(@_), qw(LICENSE CONTRIBUTING Changes);
+    _uniq($self->$orig(@_), qw(LICENSE CONTRIBUTING Changes));
 };
 
 has changes_version_columns => (
@@ -127,6 +126,11 @@ sub configure
     warn '[@Author::ETHER] no "bash" executable found; skipping Run::AfterBuild commands to update .ackrc and .latest symlink', "\n"
         if not $has_bash;
 
+    # NOTE! since the working directory has not changed to $zilla->root yet,
+    # if running this code via a different mechanism than dzil <command>, file
+    # operations may be looking at the wrong directory! Take this into
+    # consideration when running tests!
+
     my $has_xs =()= glob('*.xs');
     warn '[@Author::ETHER] XS-based distribution detected.', "\n" if $has_xs;
     die '[@Author::ETHER] no Makefile.PL found in the repository root: this is not very nice for contributors!', "\n"
@@ -149,9 +153,9 @@ sub configure
         [ 'PromptIfStale' => 'stale modules, build' => { phase => 'build', module => [ $self->meta->name ] } ],
         [ 'PromptIfStale' => 'stale modules, release' => { phase => 'release', check_all_plugins => 1, check_all_prereqs => 1 } ],
 
-        # ExecFiles, ShareDir
-        [ 'ExecDir'             => { dir => 'script' } ],
-        'ShareDir',
+        # ExecFiles
+        (-d ($self->payload->{'ExecDir.dir'} // 'script') || any { /^ExecDir\./ } keys %{ $self->payload })
+            ? [ 'ExecDir'       => { dir => 'script' } ] : (),
 
         # Finders
         [ 'FileFinder::ByName'  => Examples => { dir => 'examples' } ],
@@ -171,7 +175,7 @@ sub configure
         [ 'Test::Compile'       => { ':version' => '2.039', bail_out_on_fail => 1, xt_mode => 1,
             script_finder => [qw(:ExecFiles @Author::ETHER/Examples)] } ],
         [ 'Test::NoTabs'        => { ':version' => '0.08', finder => [qw(:InstallModules :ExecFiles @Author::ETHER/Examples :TestFiles @Author::ETHER/ExtraTestFiles)] } ],
-        [ 'Test::EOL'           => { ':version' => '0.14' } ],
+        [ 'Test::EOL'           => { ':version' => '0.14', finder => [qw(:InstallModules :ExecFiles @Author::ETHER/Examples :TestFiles @Author::ETHER/ExtraTestFiles)] } ],
         'MetaTests',
         [ 'Test::CPAN::Changes' => { ':version' => '0.008' } ],
         'Test::ChangesHasContent',
@@ -196,6 +200,7 @@ sub configure
         [
             ($self->surgical_podweaver ? 'SurgicalPodWeaver' : 'PodWeaver') => {
                 $self->surgical_podweaver ? () : ( ':version' => '4.005' ),
+                -f 'weaver.ini' ? () : ( config_plugin => '@Author::ETHER' ),
                 replacer => 'replace_with_comment',
                 post_code_replacer => 'replace_with_nothing',
             }
@@ -267,13 +272,13 @@ sub configure
         ( -e 'README.md' ?
             [ 'Run::AfterRelease' => 'remove old READMEs' => { ':version' => '0.038', quiet => 1, eval => q!unlink 'README.md'! } ]
             : ()),
-        [ 'Git::Commit'         => 'release snapshot' => { ':version' => '2.020', add_files_in => ['.'], allow_dirty => [ grep { -e } uniq 'README.md', 'README.pod', $self->copy_files_from_release ], commit_msg => '%N-%v%t%n%n%c' } ],
+        [ 'Git::Commit'         => 'release snapshot' => { ':version' => '2.020', add_files_in => ['.'], allow_dirty => [ grep { -e } _uniq('README.md', 'README.pod', $self->copy_files_from_release) ], commit_msg => '%N-%v%t%n%n%c' } ],
         [ 'Git::Tag'            => { tag_format => 'v%v', tag_message => 'v%v%t' } ],
         $self->server eq 'github' ? [ 'GitHub::Update' => { ':version' => '0.40', metacpan => 1 } ] : (),
 
         [ 'BumpVersionAfterRelease::Transitional' => { ':version' => '0.004', global => 1 } ],
         [ 'NextRelease'         => { ':version' => '5.033', time_zone => 'UTC', format => '%-' . ($self->changes_version_columns - 2) . 'v  %{yyyy-MM-dd HH:mm:ss\'Z\'}d%{ (TRIAL RELEASE)}T' } ],
-        [ 'Git::Commit'         => 'post-release commit' => { ':version' => '2.020', allow_dirty => [ 'Changes' ], allow_dirty_match => '^lib/.*\.pm$', commit_msg => 'increment $VERSION after release' } ],
+        [ 'Git::Commit'         => 'post-release commit' => { ':version' => '2.020', allow_dirty => [ 'Changes' ], allow_dirty_match => '^lib/.*\.pm$', commit_msg => 'increment $VERSION after %v release' } ],
         'Git::Push',
     );
 
@@ -357,6 +362,8 @@ sub _pause_config
     my ($username, $password) = map { my (undef, $val) = split ' ', $_; $val } $file->lines;
 }
 
+sub _uniq { keys %{ +{ map { $_ => undef } @_ } } }
+
 __PACKAGE__->meta->make_immutable;
 
 __END__
@@ -371,7 +378,7 @@ Dist::Zilla::PluginBundle::Author::ETHER - A plugin bundle for distributions bui
 
 =head1 VERSION
 
-version 0.093
+version 0.094
 
 =head1 SYNOPSIS
 
@@ -404,11 +411,9 @@ following F<dist.ini> (following the preamble), minus some optimizations:
     check_all_prereqs = 1
 
 
-    ;;; ExecFiles, ShareDir
+    ;;; ExecFiles
     [ExecDir]
-    dir = script
-
-    [ShareDir]
+    dir = script    ; only if script dir exists
 
 
     ;;; Finders
@@ -460,6 +465,12 @@ following F<dist.ini> (following the preamble), minus some optimizations:
 
     [Test::EOL]
     :version = 0.14
+    finder = :InstallModules
+    finder = :ExecFiles
+    finder = Examples
+    finder = :TestFiles
+    finder = ExtraTestFiles
+
     [MetaTests]
     [Test::CPAN::Changes]
     :version = 0.008
@@ -474,7 +485,7 @@ following F<dist.ini> (following the preamble), minus some optimizations:
     [Test::Pod::No404s]
     [Test::Kwalitee]
     :version = 2.06
-    filename => xt/author/kwalitee.t
+    filename = xt/author/kwalitee.t
     [MojibakeTests]
     [Test::ReportPrereqs]
     :version = 0.019
@@ -492,6 +503,7 @@ following F<dist.ini> (following the preamble), minus some optimizations:
 
     [PodWeaver] (or [SurgicalPodWeaver])
     :version = 4.005
+    config_plugin = @Author::ETHER ; unless weaver.ini is present
     replacer = replace_with_comment
     post_code_replacer = replace_with_nothing
 
@@ -649,15 +661,18 @@ following F<dist.ini> (following the preamble), minus some optimizations:
     [BumpVersionAfterRelease::Transitional]
     :version = 0.004
     global = 1
+
     [NextRelease]
     :version = 5.033
     time_zone = UTC
     format = %-8v  %{uyyy-MM-dd HH:mm:ss'Z'}d%{ (TRIAL RELEASE)}T
+
     [Git::Commit / post-release commit]
     :version = 2.020
     allow_dirty = Changes
     allow_dirty_match = ^lib/.*\.pm$
-    commit_msg = increment $VERSION after release
+    commit_msg = increment $VERSION after %v release
+
     [Git::Push]
 
     [Run::AfterRelease / install release]
@@ -826,6 +841,10 @@ Plugins are not loaded until they are actually needed, so it is possible to
 C<--force>-install this plugin bundle and C<-remove> some plugins that do not
 install or are otherwise problematic.
 
+If a F<weaver.ini> is present in the distribution, pod is woven using it;
+otherwise, the behaviour is as with a F<weaver.ini> containing the single line
+C<[@Author::ETHER]>.
+
 =head1 NAMING SCHEME
 
 =for stopwords KENTNL
@@ -833,6 +852,20 @@ install or are otherwise problematic.
 This distribution follows best practices for author-oriented plugin bundles; for more information,
 see L<KENTNL's distribution|Dist::Zilla::PluginBundle::Author::KENTNL/NAMING-SCHEME>.
 
+=head1 SEE ALSO
+
+=over 4
+
+=item *
+
+L<Pod::Weaver::PluginBundle::Author::ETHER>
+
+=item *
+
+L<Dist::Zilla::MintingProfile::Author::ETHER>
+
+=back
+
 =head1 SUPPORT
 
 =for stopwords irc
